package com.eitc.web.controller.common;

import com.eitc.common.config.EitcConfig;
import com.eitc.common.constant.Constants;
import com.eitc.common.core.controller.BaseController;
import com.eitc.common.utils.StringUtils;
import com.eitc.common.utils.file.FileUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;


/**
 * 通用请求处理
 *
 * @author eitc
 */
@RestController
@RequestMapping("/download")
public class DownloadController extends BaseController {
    private static final Logger log = LoggerFactory.getLogger(DownloadController.class);

    /**
     * 硬件app
     */
    @GetMapping("/hardware")
    public void hardware(HttpServletRequest request, HttpServletResponse response) {
        try {
            String resource = "/profile/app/huishitong.apk";
            resourceDownload(resource, request, response);
        } catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    @GetMapping("/hospital")
    public void hospital(HttpServletRequest request, HttpServletResponse response) {
        try {
            String resource = "/profile/app/kouqiangyiyuan_1.0.0_1_240830_release.apk";
            resourceDownload(resource, request, response);
        } catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    @GetMapping("/document")
    public void document(HttpServletRequest request, HttpServletResponse response) {
        try {
            String resource = "/profile/app/document.pdf";
            resourceDownload(resource, request, response);
        } catch (Exception e) {
            log.error("下载文件失败", e);
        }
    }

    public void resourceDownload(String resource, HttpServletRequest request, HttpServletResponse response) throws Exception {
            if (!FileUtils.checkAllowDownload(resource)) {
                throw new Exception(StringUtils.format("资源文件({})非法，不允许下载。 ", resource));
            }
            // 本地资源路径
            String localPath = EitcConfig.getProfile();
            // 数据库资源地址
            String downloadPath = localPath + StringUtils.substringAfter(resource, Constants.RESOURCE_PREFIX);
            // 下载名称
            String downloadName = StringUtils.substringAfterLast(downloadPath, "/");
            response.setContentType(MediaType.APPLICATION_OCTET_STREAM_VALUE);
            FileUtils.setAttachmentResponseHeader(response, downloadName);
            FileUtils.writeBytes(downloadPath, response.getOutputStream());
    }

}
